<!-- DOC_TYPE: INDEX -->

# Architecture

## Runtime Modules

- [Core](./core.md)
- [System](./system.md)
- [Notifications](./notifications.md)
- [Booking](./booking.md)
- [Cabinet](./cabinet.md)
- [Showcase](./showcase.md)

## Note

CLI architecture documentation moved to the companion package `codex-django-cli`.
This repository documents the runtime package only.
